@@ -1,31 +1,36 @@
 /* error.c - Error-management and messaging routines.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
+ * Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
-/* C89 */
-#include <errno.h>
-#include <string.h>
-#include <stdarg.h>
-#include <stdlib.h>
-#include <stdio.h>
-/* Gettext */
-#include <gettext.h> /* will include <libintl.h> if ENABLE_NLS */
+
+#include <errno.h>	/* C89 */
+#include <string.h>	/* C89 */
+#include <stdarg.h>	/* C89 */
+#include <stdlib.h>	/* C89 */
+#include <stdio.h>	/* C89 */
+#include "gettext.h"	/* Gnulib/gettext */
 #define _(String) gettext(String)
-/* gnulib */
-#include <vasprintf.h>
-#include <progname.h>
-/* common */
+#include "vasprintf.h"	/* Gnulib */
+#include "progname.h"	/* Gnulib */
 #include "error.h"
 
 struct MessageHeader {
