@@ -1,31 +1,37 @@
 /* string-utils.c - Functions dealing with string contents.
  *
- * Copyright (C) 2001  Oskar Liljeblad
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
+ * Oskar Liljeblad
  *
- * This file is part of the file renaming utilities (renameutils)
- * and regex-markup.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This software is copyrighted work licensed under the terms of the
- * GNU General Public License. Please consult the file `COPYING' for
- * details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #if HAVE_CONFIG_H
 #include <config.h>
 #endif
-/* C89 */
-#include <ctype.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-/* gnulib */
-#include <xalloc.h>
-/* common */
+#include <ctype.h>		/* C89 */
+#include <stdarg.h>		/* C89 */
+#include <stdio.h>		/* C89 */
+#include <string.h>		/* C89 */
+#include <stdlib.h>		/* C89 */
+#include "xalloc.h"		/* Gnulib */
+#include "strndup.h"		/* Gnulib */
+#include "xvasprintf.h"		/* Gnulib */
 #include "common.h"
 #include "error.h"
 #include "string-utils.h"
-#include "memory.h"
 
 /**
  * Return a zero-based of a character in a string.
@@ -335,7 +341,7 @@ string_strip_trailing_c(char *str, char stripchar)
 	return b-a;
 }
 
-/* FIXME: document */
+/* XXX: document */
 int
 string_strip_leading(char *str, const char *stripchars)
 {
@@ -351,7 +357,7 @@ string_strip_leading(char *str, const char *stripchars)
 	return a-b;
 }
 
-/* FIXME: document */
+/* XXX: document */
 int
 string_strip_leading_c(char *str, char stripchar)
 {
